==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odt/dom/SectionStartMarker.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.filter.odt.dom;

import java.lang.ref.WeakReference;
import org.apache.xml.serializer.SerializationHandler;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import com.openexchange.office.filter.odf.AttributesImpl;
import com.openexchange.office.filter.odf.DLList;
import com.openexchange.office.filter.odf.Namespaces;
import com.openexchange.office.filter.odf.SaxContextHandler;

public class SectionStartMarker implements ISectionWriter {

	private WeakReference<SectionEndMarker> sectionEndMarkerRef = null;

	final private AttributesImpl attributes;

	public SectionStartMarker(Attributes attributes) {
		this.attributes = new AttributesImpl(attributes);
	}

	public void setEndMarker(SectionEndMarker sectionEndMarker) {
		sectionEndMarkerRef = new WeakReference<SectionEndMarker>(sectionEndMarker);
	}

	@Override
	public void writeObject(SerializationHandler output) {

		// don't write this object without knowing if the corresponding end marker is stored within the same list

		return;
	}

	@Override
	public void writeSection(SerializationHandler output, DLList<Object> parentList)
		throws SAXException {

		// taking care that the end marker is available (in the same parent list) otherwise don't open this element

		if(sectionEndMarkerRef!=null) {
			final SectionEndMarker sectionEndMarker = sectionEndMarkerRef.get();
			if(sectionEndMarker!=null) {
				if(parentList.contains(sectionEndMarker)) {
					SaxContextHandler.startElement(output, Namespaces.TEXT, "section", "text:section");
					attributes.write(output);
				}
			}
		}
	}
}

==> open-xchange-documents-backend_7.10.2.orig.tar.bz2: open-xchange-documents-backend-7.10.2/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odt/dom/SectionStartMarker.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.filter.odt.dom;

import java.lang.ref.WeakReference;
import org.apache.xml.serializer.SerializationHandler;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import com.openexchange.office.filter.core.DLList;
import com.openexchange.office.filter.odf.AttributesImpl;
import com.openexchange.office.filter.odf.Namespaces;
import com.openexchange.office.filter.odf.SaxContextHandler;

public class SectionStartMarker implements ISectionWriter {

	private WeakReference<SectionEndMarker> sectionEndMarkerRef = null;

	final private AttributesImpl attributes;

	public SectionStartMarker(Attributes attributes) {
		this.attributes = new AttributesImpl(attributes);
	}

	public void setEndMarker(SectionEndMarker sectionEndMarker) {
		sectionEndMarkerRef = new WeakReference<SectionEndMarker>(sectionEndMarker);
	}

	@Override
	public void writeObject(SerializationHandler output) {

		// don't write this object without knowing if the corresponding end marker is stored within the same list

		return;
	}

	@Override
	public void writeSection(SerializationHandler output, DLList<Object> parentList)
		throws SAXException {

		// taking care that the end marker is available (in the same parent list) otherwise don't open this element

		if(sectionEndMarkerRef!=null) {
			final SectionEndMarker sectionEndMarker = sectionEndMarkerRef.get();
			if(sectionEndMarker!=null) {
				if(parentList.contains(sectionEndMarker)) {
					SaxContextHandler.startElement(output, Namespaces.TEXT, "section", "text:section");
					attributes.write(output);
				}
			}
		}
	}
}
